<?php
/**
Plugin Name: Default Startup Folder for Real Media Library
Description: Adds an option field to select a default media library startup folder for Real Media Library
Author: Matthias Günter
Version: 1.0.7
Author URI: https://matthias-web.com
Licence: GPLv2
*/

// exit if accessed directly
if( ! defined( 'ABSPATH' ) ) exit;


// check if class already exists
if( !class_exists('default_real_media_library_folder') ) :
	
class default_real_media_library_folder {
    /**
     * C'tor
     */
	function __construct() {
	    add_action('init',                                  array($this, 'init'));
	}
	
	public function init() {
        if ( !defined('RML_VERSION') || version_compare(RML_VERSION, "3.2", "<")) {
            if ( is_admin() ) {
                add_action( 'admin_notices',                array( $this, 'admin_notices' ), 10, 3 );
            }
        }else{
        	$isV4 = version_compare(RML_VERSION, "4.0.0", ">=");
        	
    	    // Actions and filters
    		add_filter( 'RML/Filter/PostsClauses',          array( $this, 'posts_clauses' ), 10, 4 );
    		if ($isV4) {
    			add_filter( 'RML/Localize',					array( $this, 'js_localize' ) );
    			add_action( 'RML/Scripts',					array( $this, 'backend_scripts' ) );
    		}else{
    			add_filter( 'RML/Backend/JS_Localize',		array( $this, 'js_localize' ) );
    			add_action( 'RML/Backend/Scripts',			array( $this, 'backend_scripts' ) );
    		}
    		
    		add_action( 'wp_ajax_query-attachments',		array( $this, 'wp_ajax_query_attachments' ), -1 );

    		// Gettext for list mode
    		if (isset($_REQUEST["mode"])) {
    			$mode = $_REQUEST["mode"];
    		}else{
    			$mode = get_user_option( 'media_library_mode', get_current_user_id() ) ? get_user_option( 'media_library_mode', get_current_user_id() ) : 'grid';
    		}
    		if (isset($_GET["rml_folder"]) && $_GET["rml_folder"] == "-2" && $mode === "list") {
    		    add_filter( 'gettext',                      array( $this, 'gettext' ), 10, 3 );
    		}
    		
    		// Register user settings
    		require_once("UserSetting.class.php");
    		add_rml_user_settings_box("defaultFolder", new default_real_media_library_folder_box($this));
        }
	}
	
	/**
	 * Avoid performance issues and response an empty array.
	 */
	public function wp_ajax_query_attachments() {
		if (isset($_REQUEST["query"]) && is_array($_REQUEST["query"]) && isset($_REQUEST["query"]["rml_folder"])
			&& $_REQUEST["query"]["rml_folder"] == "-2") {
			wp_send_json_success(array());
		}
	}
	
	public function js_localize($array) {
		$array["lang"]["defaultFolderNoneLabel"] = $this->getNoItemsText();
		$array["lang"]["defaultFolderLoadingLabel"] = __("Loading...");
		return array_merge($array, array(
			"defaultFolder" => $this->getDefaultFolder()
		));
	}
	
	/**
	 * Include script
	 */
	public function backend_scripts() {
		wp_enqueue_script('rml-default-folder', plugins_url( 'script.js', __FILE__ ), array(), '1.0.5');
	}
	
	/**
	 * Modify text in list table
	 */
	public function gettext($translation, $text, $domain) {
	    return $text === "No media files found." && $domain === "default"
	        ? $this->getNoItemsText() : $translation;
	}
	
	/**
	 * Modify fields to a fast select query when the setting "Load no items until folder is selected" is configured.
	 */
	public function posts_clauses($clauses, $query, $folderId, $root) {
	    if ($folderId == "-2") {
    	    $clauses["where"] = " AND 1=0";
    	    $clauses["limits"] = "LIMIT 0, 1";
    	    $clauses["_restrictRML"] = true;
	    }
	    return $clauses;
	}
	
	public function getNoItemsText() {
	    return __("Please select a folder to show items."); // @TODO languages
	}
	
	public function getDefaultFolder() {
		$val = get_user_meta(get_current_user_id(), "rmlDefaultFolder", true);
		if (empty($val)) {
			return 'all';
		}
		return $val;
	}
	
	public function admin_notices() {
?>
<div class="notice notice-error is-dismissible">
    <p>The plugin <a href="https://codecanyon.net/item/wordpress-real-media-library-media-categories-folders/13155134" target="_blank"><b>Real Media Library</b></a> is not active (maybe not installed neither) or the version of Real Media Library is < 3.2 (please update).</p>
</div>
<?php
	}
}


// initialize
// new default_real_media_library_folder(); // @deprecated


// class_exists check 
endif;
	
?>